/*
  nixie_write_zero - sample code using the Nixie library 
                      for controlling the Ogi Lumen nixie tube driver.
  Created by Lionel Haims, July 25, 2008.
  Released into the public domain.
*/

// include the library
#include <Nixie.h>

// note the digital pins of the arduino that are connected to the nixie driver
#define dataPin 5  // data line or SER
#define clockPin 3 // clock pin or SCK
#define latchPin 4 // latch pin or RCK

// note the number of digits (nixie tubes) you have (buy more, you need more)
#define numDigits 4

// just some defines to simplify the examples
#define shortDelay 200
#define longDelay 3000
#define maxCount 9999

// Create the Nixie object
// pass in the pin numbers in the correct order
//this sets all three to outputs
Nixie nixie(dataPin, clockPin, latchPin);

  //number of hits
  int count = 0;
  
  //hits recorded in ten second bins, for counts per minute
  int countArray[6];
  //which bin is active
  int activeBin;
  
  //the time, for incrementing the active bin every 10 seconds
  unsigned long lastUpdate;
  
void setup()
{
//  Serial.begin(9600);

//  Clear the display if you wish
  nixie.clear(numDigits);
  

//  interrupt number 0 (first argument) is pin 2
  attachInterrupt(0, click, FALLING);
  

//this is the pin for the piezo
  pinMode(8, OUTPUT);

//  this is the geiger count input pin
  pinMode(2, INPUT);


//  these are the mode selection pins...there's only two for now
  pinMode(9,INPUT_PULLUP);
  pinMode(10,INPUT_PULLUP);


  countArray[0] = 0;
  countArray[1] = 0;
  countArray[2] = 0;
  countArray[3] = 0;
  countArray[4] = 0;
  countArray[5] = 0;

  activeBin = 0;
  lastUpdate = millis();

}

void loop()
{
  
//  first mode, just display the total number of hits
  if(digitalRead(9) == LOW){
  // Write out the number using a zero padding.
  // The number will be right justified with "0"s on the left 
  // if the number doesn't use all tubes.
      nixie.writeNumZero( count, numDigits);
     }
     
     
//  second mode, counts per minute
    else if(digitalRead(10) == LOW){
      
//  variables for averaging
      int sum = 0;
      int num = 0;
      
      
//get the average bin value, skipping any zero bins and skipping the active bin     
      for(int i = 0; i < 6; i++){
        if(i == activeBin){ continue; }
//        if(countArray[i] != 0){
          sum += countArray[i];
          num++;
//        }
      }

//bins are filled in 1 seconds, so multiply average bin value by 60 to get counts per minute
//assuming integer division works like in regular C
      
      //divide by zero at your own peril
      if(num != 0){
        nixie.writeNumZero( (sum / num)*6, numDigits);
      }
//      nixie.writeNumZero( 26, numDigits);

    }
   
   
   
//  all the other output modes   
    else{
      
      nixie.writeNumZero( 404, numDigits);
    }
     
//    Serial.println(i);
 
      
  
    
    //this is the active bin updating section
    //rollover if you are in bin 5
    //also, have to 
    if((millis() - lastUpdate)  > 10000){
      if(activeBin != 5){
      activeBin++;
      }
      else{
        activeBin = 0;
      }

//set new bin back to zero counts
      countArray[activeBin] = 0;
      lastUpdate = millis();
    }



  //don't really need to be updating the display once a microsecond
    delay(shortDelay);


}


void click(){
    count++;
    countArray[activeBin]++;
    tone(8, 440, 30);   //pin 8, 440 hertz, 30 milli seconds
//    Serial.print("interrupt: ");
//    Serial.println(count);
}

